This release mostly comprises improvements and refactoring of the API that will improve the user-friendliness and will reduce interdependencies of individual classes or modules.

**Note**: due to the applied API changes this release is not fully backward compatible with the previous release, as it includes renaming and refactoring of some modules and classes as specified below in section API changes. However, most of the standard routines and toplevel class imports remain functional compared with previous versions. In case any errors occur when running scripts based on earlier versions of geonum, it should be straightforward to fix it (it will be likely only a different import). E.g. a statement 

```
from geonum.base import GeoPoint
```

would now be:

```
from geonum.geopoint import GeoPoint
```

Or simply:

```
from geonum import GeoPoint
```

which works in the current and all previous versions.

## New features

- More options for computation of elevation profiles (mapping of coordinates).
- Added method 'delete_all_local_srtm_files' to new module topoaccessbase.py (should be self explanatory).

## API changes

- Removed base.py module and moved the two base classes GeoPoint and GeoVector3D into separate modules (geopoint.py and geovector3d.py).
- New module elevationprofile.py (containing class ElevationProfile which was previously in processing.py).
- Major improvements and clean up of topogaphy data access classes.
- Renamed and simplified factory class TopoAccess -> TopoDataAccess and moved into own module topodataaccess.py (previously in topodata.py).
- Renamed class TopoFile to TopoDataAccess and moved into new module topoaccessbase.py.
- Moved Etopo1Access and SRTMAccess classes from topodata.py to new module topoaccessbase.py.
- Moved all custom exceptions from topodata.py to new module exceptions.py.

## Other updates

- Removed LatLon dependency (now only LatLon23 is required).
- Updated installation details and added conda environment file for python 3.X (geonum_env_py3.yml).
- Updated requirements.txt file.
- Included more unit tests.
- Set-up automatic tests for Python 2.7 and 3.5+ using Travis CI. 
- Bug fixes.
- Updated website and code documentation.